@@ -5,8 +5,10 @@ v0.1 Update graph by line instead of scatter
 v0.2 add multirenaming option
 v0.3 naming fix from plotyfermy compatibility
 v0.4 add time slice option to fanodygrowth function
-v0.5 add method to average replciates
+v0.5 add method to average replicates
+v0.6 bug fix for replicates
 ==> next step add minimal DeltaBiomassProxy for fanodygrowth function
+==> add max OD to fermgrowth
 ==> next step calcul max Proxxy at max slope
     if dfslope.min()<limite:
             indexODmaxslope = dfslope.loc[dataafterslope<=0.005].first_valid_index()
@@ -28,7 +30,7 @@ This file is part of Fermy.
     along with Fermy.  If not, see <https://www.gnu.org/licenses/>.
 """
 
-__version__ = 0.5
+__version__ = 0.6
 
 
 import pandas as pd
@@ -147,10 +149,11 @@ def fanodygrowth(data: pd.DataFrame, percentofmax:float=0.05, usemax:bool=False,
     
     Parameters:
     ----------
-    usemax: allow users by use chose between normalization methods:
+    usemax: allow users to choose between normalization methods:
             average of the first five points
             or 
             percentage of the maximal value of dataset
+    
     percentofmax: allow users to change the percentage of
             maximal value used
     
@@ -159,7 +162,7 @@ def fanodygrowth(data: pd.DataFrame, percentofmax:float=0.05, usemax:bool=False,
             the provided number of hours
     
     deltathreshold: allow users to exclude data without a minimal
-                Biomass proxy delta between min and max of the column. 
+                Biomass proxy delta between min and max of the column.
     
     
     Output:
@@ -210,6 +213,7 @@ def fanodygrowth(data: pd.DataFrame, percentofmax:float=0.05, usemax:bool=False,
         .rename(columns = {0:"maximal_growth_rate_per_h", 1 : "lagtime_h"})  # renaming
         .assign(lagtime_h = lambda df: -df["lagtime_h"]/df["maximal_growth_rate_per_h"])  #compute lagtime (basted on intercept already and wrongly named lagtime)
         .assign(maximal_growth_rate_time_h = indexmax)  #add time of mumax
+        .assign(maximal_od = datatemp.max())  # max od of original dataframe
         .round(2)  #round at two decimals
             )
     
@@ -304,7 +308,7 @@ def customedrenamefunction(DFdata:pd.DataFrame, dicorenamingrullsuserdef:Dict, i
 
 def meanreplicates(dataframe:pd.DataFrame, sepchar:str):
     """Function to average data from a pandas DataFrame grouping by left part of column name
-    after splitting by a defined separated character (sepcahr)
+    after splitting by a defined separated character (sepchar)
     Input:
     -----
     DataFrame
@@ -315,7 +319,7 @@ def meanreplicates(dataframe:pd.DataFrame, sepchar:str):
     return a DataFrame with averaged data per base name
     
     """
-    listofsamplebasename = [column.split("_")[0] for column in dataframe.columns]
+    listofsamplebasename = [column.split(sepchar)[0] for column in dataframe.columns]
     listofsamplename = dataframe.columns.to_list()
     if len(listofsamplebasename) == len(listofsamplename):
         mapping = dict(zip(listofsamplename, listofsamplebasename))
